NAME
Dist::Zilla::Plugin::AutomationPolicy - add an automation policy to a distribution
VERSION
version v0.1.1
SYNOPSIS
In the dist.ini:
[AutomationPolicy]
-version = v0.2.2
description = The automation policy for Foo-Bar-Baz
template = human_supervised
models = claude-opus-4-7
models = claude-opus-4-8
DESCRIPTION
This plugin will create a machine-readable CPAN-META/automation-policy.json file in your distribution, using Dist::AutomationPolicy.
It allows authors to specify the use of automation in generating their modules, and what automated contributions they will accept.
OPTIONS
The options correspond to attributes from Dist::AutomationPolicy. The more important ones are listed here.
-version
This lets you specify the minimum version of Dist::AutomationPolicy to use. (Do not confuse this with the version attribute.)
description
This is an optional short description of the automation policy.
document
This is an optional name of the human-readable AI_POLICY.md file.
It is not generated by current versions of Dist::AutomationPolicy. You have to create it yourself, and ensure it is consistent with this file.
template
This is an attribute for specifying common use-cases:
- no_automation
-
No code is generated beyond the toolchain.
No automated contributions are accepted.
No automated actions beyond basic scripting that might comment on issues or pull requests.
- issues_only
-
No code is generated beyond the toolchain.
Automated contributions or actions may submit comments and issues.
- human_supervised
-
Code may be generated by AI or LLMs, and patches or pull requests may be submitted by contributors or agents run by the maintainers.
However, all code changes and releases must be reviewed and approved by the maintainers.
- data_driven_updates
-
A use case for this is a cron job that checks for an updated external data source, adapts that data into a new version of a module, and uploads a new release to CPAN.
Code is updated from external sources, and released automatically.
Automated contributions may post comments or issues.
- full_automation
-
Code is generated by AI or LLMs, automated contributions can submit patches or pull requests, and agents operated by the maintainers can make changes to the code and release automatically.
This is discouraged.
See Dist::AutomationPolicy for all supported values and an explanation of what they mean.
code_generation
This outlines how automated tools will generate or update the code and documentation. See Dist::AutomationPolicy for values.
automated_contributions
This outlines what is accepted from users or agents that are not controlled by or explicitly granted access by the maintainers. See Dist::AutomationPolicy for values.
automated_actions
This outlines automated changes made by users or agents that are controlled or explicitly granted access by the project maintainers. See Dist::AutomationPolicy for values.
models
This is an optional name of models used for Model IDs used for "automated_actions", and (when known) automated_contributions.
Model IDs should come from https://docs.aimlapi.com/api-references/model-database.
SEE ALSO
SOURCE
The development version is on github at https://github.com/robrwo/perl-Dist-Zilla-Plugin-AutomationPolicy and may be cloned from https://github.com/robrwo/perl-Dist-Zilla-Plugin-AutomationPolicy.git
SUPPORT
Only the latest version of this module will be supported.
This module requires Perl v5.24 or later, based on the minimum Perl supported by Dist::Zilla.
Reporting Bugs and Submitting Feature Requests
Please report any bugs or feature requests on the bugtracker website https://github.com/robrwo/perl-Dist-Zilla-Plugin-AutomationPolicy/issues
When submitting a bug or request, please include a test-file or a patch to an existing test-file that illustrates the bug or desired feature.
If the bug you are reporting has security implications which make it inappropriate to send to a public issue tracker, then see SECURITY.md for instructions how to report security vulnerabilities.
AUTHOR
Robert Rothenberg <perl@rhizomnic.com>
CONTRIBUTOR
Leon Timmermans <fawaka@gmail.com>
COPYRIGHT AND LICENSE
This software is Copyright (c) 2026 by Robert Rothenberg.
This is free software, licensed under:
The Artistic License 2.0 (GPL Compatible)